#!/bin/sh
# $Revision: $
# Luis Mondesi < lemsx1@gmail.com >
#
# DESCRIPTION: Functions needed by Splashy init scripts. Inspired in part by fbsplash.
# LICENSE: GPL

# do not edit this file. please edit /etc/default/debian instead
# variables need to match with those defined in /etc/splashy/config.xml
# since this file is sourced by other files, we are careful not to override
# variables:
if [ "x$spl_pidfile" = "x" ]; then
    spl_pidfile="/etc/splashy/splashy.pid"
fi

if [ "x$spl_fifo" = "x" ]; then
    spl_fifo="/etc/splashy/splashy.fifo"
fi

# our binary name (daemon): 
if [ "x$NAME" = "x" ]; then
    NAME="splashy"
fi

# our binary full path
if [ "x$DAEMON" = "x" ]; then
    DAEMON="/sbin/splashy"
fi

if [ -r /etc/default/splashy ]; then
    source /etc/default/splashy
fi

# checks if splashy is running and returns PID
splashy_get_pid() {
    # algorithm:
    # if pidof exits, return pid from this, else
    # if pid file is readable, read and find common name with ps
    # if found, check if this matches with our $NAME and return this pid
    # else, try to find our pid without using a PID file
    if [ -x "/bin/pidof" ]; then
        # we only care about a single PID (-s)
        echo $(/bin/pidof -s "$DAEMON")
        return 0
    fi
    # fall back
    if [ -r "$spl_pidfile" ]; then
        m_pid=$(cat "$spl_pidfile")
        if [ "x$m_pid" != "x" ]; then
            # cpm name holding PID file against our own: splashy
            if [ "x$(ps -p "$m_pid" -o comm=)" = "x$NAME" ]; then
                echo $m_pid
                return 0
            fi
        fi
    fi
    # fall back
    # else we find the running version of splashy and return it's pid
    # or blank if not found
    # TODO the name of the binary running might not be 'splashy'
    echo $(ps -C $NAME -o pid=)
    return 0
}

# Sends commands to the splashy FIFO
splashy_cmd_send() {
    # sanity checks
    m_pid=$(splashy_get_pid)
    if [ ! -p "$spl_fifo" -o "x$m_pid" = "x" ]; then
        echo "Splashy is not running... no commands can be sent"
        echo "Please verify /etc/default/spalshy and /etc/splashy/config.xml for correctness"
        return 1
    fi
    echo $* > "$spl_fifo" &
    return 0
}

